.. _compatibility:

.. image:: ../artwork/cicada.png
  :width: 200px
  :align: right

Compatibility
=============

A quick disclaimer on backwards-compatibility for Cicada users:

Cicada follows the `Semantic Versioning <http://semver.org>`_ standard for
assigning version numbers in a way that has specific meaning.  As of this
writing Cicada releases are still in the `0.y.z` development phase, which
means (among other things) that the API may change at any time.  We try not to
be abusive about it, but you should be prepared for the occasional bump on the
road to the 1.0 release.



